@@ -35,6 +35,9 @@ void dm_task_destroy(struct dm_task *dmt)
 		free(t);
 	}
 
+	if (dmt->newname)
+		free(dmt->newname);
+
 	if (dmt->dmi)
 		free(dmt->dmi);
 
@@ -62,6 +65,16 @@ int dm_task_set_ro(struct dm_task *dmt)
 	return 1;
 }
 
+int dm_task_set_newname(struct dm_task *dmt, const char *newname)
+{
+	if (!(dmt->newname = strdup(newname))) {
+		log("dm_task_set_newname: strdup(%s) failed", newname);
+		return 0;
+	}
+
+	return 1;
+}
+
 struct target *create_target(uint64_t start,
 				     uint64_t len,
 				     const char *type, const char *params)
@@ -154,15 +167,25 @@ static struct dm_ioctl *_flatten(struct dm_task *dmt)
 		count++;
 	}
 
+	if (count && dmt->newname) {
+		log("targets and newname are incompatible");
+		return NULL;
+	}
+
+	if (dmt->newname)
+		len += strlen(dmt->newname) + 1;
+
 	if (!(dmi = malloc(len)))
 		return NULL;
 
+	memset(dmi, 0, len);
+
 	strncpy(dmi->version, DM_IOCTL_VERSION, sizeof(dmi->version));
 	dmi->data_size = len;
 	strncpy(dmi->name, dmt->dev_name, sizeof(dmi->name));
 	dmi->suspend = (dmt->type == DM_DEVICE_SUSPEND) ? 1 : 0;
 	dmi->open_count = 0;
-	dmi->minor = -1;
+	dmi->minor = dmt->minor;
 	dmi->read_only = dmt->read_only;
 
 	dmi->target_count = count;
@@ -174,6 +197,9 @@ static struct dm_ioctl *_flatten(struct dm_task *dmt)
 		if (!(b = _add_target(t, b, e)))
 			goto bad;
 
+	if (dmt->newname)
+		strcpy(b, dmt->newname);
+
 	return dmi;
 
  bad:
@@ -225,6 +251,10 @@ int dm_task_run(struct dm_task *dmt)
 		command = DM_INFO;
 		break;
 
+	case DM_DEVICE_RENAME:
+		command = DM_RENAME;
+		break;
+
 	default:
 		log("Internal error: unknown device-mapper task %d",
 		    dmt->type);
